==> magnum_5.0.1.orig.tar.gz: magnum-5.0.1/magnum/drivers/heat/swarm_mode_template_def.py <==
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.
from magnum.drivers.heat import template_def
from oslo_config import cfg

CONF = cfg.CONF
DOCKER_PORT = '2375'


class SwarmModeApiAddressOutputMapping(template_def.OutputMapping):

    def set_output(self, stack, cluster_template, cluster):
        if self.cluster_attr is None:
            return

        output_value = self.get_output_value(stack)
        if output_value is not None:
            # Note(rocha): protocol should always be tcp as the docker
            # command client does not handle https (see bug #1604812).
            params = {
                'protocol': 'tcp',
                'address': output_value,
                'port': DOCKER_PORT,
            }
            value = "%(protocol)s://%(address)s:%(port)s" % params
            setattr(cluster, self.cluster_attr, value)


class SwarmModeMasterAddressesOutputMapping(template_def.OutputMapping):

    def set_output(self, stack, cluster_template, cluster):
        if self.cluster_attr is None:
            return

        _master_addresses = []
        for output in stack.to_dict().get('outputs', []):
            if output['output_key'] == 'swarm_primary_master':
                _master_addresses.append(output['output_value'][0])
            elif output['output_key'] == 'swarm_secondary_masters':
                _master_addresses += output['output_value']
        setattr(cluster, self.cluster_attr, _master_addresses)


class SwarmModeTemplateDefinition(template_def.BaseTemplateDefinition):
    """Docker swarm mode template."""

    def __init__(self):
        super(SwarmModeTemplateDefinition, self).__init__()
        self.add_parameter('cluster_uuid',
                           cluster_attr='uuid',
                           param_type=str)
        self.add_parameter('number_of_nodes',
                           cluster_attr='node_count')
        self.add_parameter('master_flavor',
                           cluster_template_attr='master_flavor_id')
        self.add_parameter('node_flavor',
                           cluster_template_attr='flavor_id')
        self.add_parameter('docker_volume_size',
                           cluster_attr='docker_volume_size')
        self.add_parameter('volume_driver',
                           cluster_template_attr='volume_driver')
        self.add_parameter('external_network',
                           cluster_template_attr='external_network_id',
                           required=True)
        self.add_parameter('fixed_network',
                           cluster_template_attr='fixed_network')
        self.add_parameter('fixed_subnet',
                           cluster_template_attr='fixed_subnet')
        self.add_parameter('tls_disabled',
                           cluster_template_attr='tls_disabled',
                           required=True)
        self.add_parameter('docker_storage_driver',
                           cluster_template_attr='docker_storage_driver')

        self.add_output('api_address',
                        cluster_attr='api_address',
                        mapping_type=SwarmModeApiAddressOutputMapping)
        self.add_output('swarm_primary_master_private',
                        cluster_attr=None)
        self.add_output('swarm_primary_master',
                        cluster_attr='master_addresses',
                        mapping_type=SwarmModeMasterAddressesOutputMapping)
        self.add_output('swarm_nodes_private',
                        cluster_attr=None)
        self.add_output('swarm_nodes',
                        cluster_attr='node_addresses')

    def get_params(self, context, cluster_template, cluster, **kwargs):
        extra_params = kwargs.pop('extra_params', {})
        # HACK(apmelton) - This uses the user's bearer token, ideally
        # it should be replaced with an actual trust token with only
        # access to do what the template needs it to do.
        osc = self.get_osc(context)
        extra_params['magnum_url'] = osc.magnum_url()

        label_list = ['rexray_preempt']

        extra_params['auth_url'] = context.auth_url

        for label in label_list:
            extra_params[label] = cluster_template.labels.get(label)

        # set docker_volume_type
        # use the configuration default if None provided
        docker_volume_type = cluster_template.labels.get(
            'docker_volume_type', CONF.cinder.default_docker_volume_type)
        extra_params['docker_volume_type'] = docker_volume_type

        return super(SwarmModeTemplateDefinition,
                     self).get_params(context, cluster_template, cluster,
                                      extra_params=extra_params,
                                      **kwargs)

    def get_env_files(self, cluster_template, cluster):
        env_files = []

        template_def.add_priv_net_env_file(env_files, cluster_template)
        template_def.add_volume_env_file(env_files, cluster)
        template_def.add_lb_env_file(env_files, cluster_template)

        return env_files

==> magnum_6.1.0.orig.tar.gz: magnum-6.1.0/magnum/drivers/heat/swarm_mode_template_def.py <==
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.
from magnum.drivers.heat import template_def
from oslo_config import cfg

CONF = cfg.CONF
DOCKER_PORT = '2375'


class SwarmModeApiAddressOutputMapping(template_def.OutputMapping):

    def set_output(self, stack, cluster_template, cluster):
        if self.cluster_attr is None:
            return

        output_value = self.get_output_value(stack)
        if output_value is not None:
            # Note(rocha): protocol should always be tcp as the docker
            # command client does not handle https (see bug #1604812).
            params = {
                'protocol': 'tcp',
                'address': output_value,
                'port': DOCKER_PORT,
            }
            value = "%(protocol)s://%(address)s:%(port)s" % params
            setattr(cluster, self.cluster_attr, value)


class SwarmModeMasterAddressesOutputMapping(template_def.OutputMapping):

    def set_output(self, stack, cluster_template, cluster):
        if self.cluster_attr is None:
            return

        _master_addresses = []
        for output in stack.to_dict().get('outputs', []):
            if output['output_key'] == 'swarm_primary_master':
                _master_addresses.append(output['output_value'][0])
            elif output['output_key'] == 'swarm_secondary_masters':
                _master_addresses += output['output_value']
        setattr(cluster, self.cluster_attr, _master_addresses)


class SwarmModeTemplateDefinition(template_def.BaseTemplateDefinition):
    """Docker swarm mode template."""

    def __init__(self):
        super(SwarmModeTemplateDefinition, self).__init__()
        self.add_parameter('cluster_uuid',
                           cluster_attr='uuid',
                           param_type=str)
        self.add_parameter('number_of_nodes',
                           cluster_attr='node_count')
        self.add_parameter('master_flavor',
                           cluster_attr='master_flavor_id')
        self.add_parameter('node_flavor',
                           cluster_attr='flavor_id')
        self.add_parameter('docker_volume_size',
                           cluster_attr='docker_volume_size')
        self.add_parameter('volume_driver',
                           cluster_template_attr='volume_driver')
        self.add_parameter('external_network',
                           cluster_template_attr='external_network_id',
                           required=True)
        self.add_parameter('fixed_network',
                           cluster_template_attr='fixed_network')
        self.add_parameter('fixed_subnet',
                           cluster_template_attr='fixed_subnet')
        self.add_parameter('tls_disabled',
                           cluster_template_attr='tls_disabled',
                           required=True)
        self.add_parameter('docker_storage_driver',
                           cluster_template_attr='docker_storage_driver')

        self.add_output('api_address',
                        cluster_attr='api_address',
                        mapping_type=SwarmModeApiAddressOutputMapping)
        self.add_output('swarm_primary_master_private',
                        cluster_attr=None)
        self.add_output('swarm_primary_master',
                        cluster_attr='master_addresses',
                        mapping_type=SwarmModeMasterAddressesOutputMapping)
        self.add_output('swarm_nodes_private',
                        cluster_attr=None)
        self.add_output('swarm_nodes',
                        cluster_attr='node_addresses')

    def get_params(self, context, cluster_template, cluster, **kwargs):
        extra_params = kwargs.pop('extra_params', {})
        # HACK(apmelton) - This uses the user's bearer token, ideally
        # it should be replaced with an actual trust token with only
        # access to do what the template needs it to do.
        osc = self.get_osc(context)
        extra_params['magnum_url'] = osc.magnum_url()

        label_list = ['rexray_preempt', 'availability_zone']

        extra_params['auth_url'] = context.auth_url
        extra_params['nodes_affinity_policy'] = \
            CONF.cluster.nodes_affinity_policy

        for label in label_list:
            extra_params[label] = cluster_template.labels.get(label)

        # set docker_volume_type
        # use the configuration default if None provided
        docker_volume_type = cluster_template.labels.get(
            'docker_volume_type', CONF.cinder.default_docker_volume_type)
        extra_params['docker_volume_type'] = docker_volume_type

        return super(SwarmModeTemplateDefinition,
                     self).get_params(context, cluster_template, cluster,
                                      extra_params=extra_params,
                                      **kwargs)

    def get_env_files(self, cluster_template, cluster):
        env_files = []

        template_def.add_priv_net_env_file(env_files, cluster_template)
        template_def.add_volume_env_file(env_files, cluster)
        template_def.add_lb_env_file(env_files, cluster_template)

        return env_files
